package betterquesting.commands.admin;

import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api2.storage.DBEntry;
import betterquesting.commands.QuestCommandBase;
import betterquesting.network.handlers.NetQuestSync;
import betterquesting.questing.QuestDatabase;
import betterquesting.storage.NameCache;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.UUID;
import net.minecraft.command.CommandBase;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.ChatComponentTranslation;

/* loaded from: betterquesting_commands_admin.jar:betterquesting/commands/admin/QuestCommandReset.class */
public class QuestCommandReset extends QuestCommandBase {
    public String getUsageSuffix() {
        return "[all|<quest_id>] [username|uuid]";
    }

    public boolean validArgs(String[] args) {
        return args.length == 2 || args.length == 3;
    }

    public List<String> autoComplete(MinecraftServer server, ICommandSender sender, String[] args) {
        ArrayList<String> list = new ArrayList<>();
        if (args.length == 2) {
            list.add("all");
            for (DBEntry<IQuest> i : QuestDatabase.INSTANCE.getEntries()) {
                list.add("" + i.getID());
            }
        } else if (args.length == 3) {
            return CommandBase.func_71530_a(args, (String[]) NameCache.INSTANCE.getAllNames().toArray(new String[0]));
        }
        return list;
    }

    public String getCommand() {
        return "reset";
    }

    public void runCommand(MinecraftServer server, CommandBase command, ICommandSender sender, String[] args) {
        String action = args[1];
        UUID uuid = null;
        if (args.length == 3) {
            uuid = findPlayerID(server, sender, args[2]);
            if (uuid == null) {
                throw getException(command);
            }
        }
        String pName = uuid == null ? "NULL" : NameCache.INSTANCE.getName(uuid);
        EntityPlayerMP player = null;
        if (uuid != null) {
            Iterator it = server.func_71203_ab().field_72404_b.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                EntityPlayerMP p = (EntityPlayerMP) it.next();
                if (p.func_146103_bH().getId().equals(uuid)) {
                    player = p;
                    break;
                }
            }
        }
        if (action.equalsIgnoreCase("all")) {
            for (DBEntry<IQuest> entry : QuestDatabase.INSTANCE.getEntries()) {
                if (uuid != null) {
                    ((IQuest) entry.getValue()).resetUser(uuid, true);
                } else {
                    ((IQuest) entry.getValue()).resetUser((UUID) null, true);
                }
            }
            if (uuid != null) {
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.reset.player_all", new Object[]{pName}));
                if (player != null) {
                    NetQuestSync.sendSync(player, (int[]) null, false, true);
                    return;
                }
                return;
            }
            sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.reset.all_all", new Object[0]));
            NetQuestSync.quickSync(-1, false, true);
            return;
        }
        try {
            int id = Integer.parseInt(action.trim());
            IQuest quest = (IQuest) QuestDatabase.INSTANCE.getValue(id);
            if (uuid != null) {
                quest.resetUser(uuid, true);
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.reset.player_single", new Object[]{new ChatComponentTranslation((String) quest.getProperty(NativeProps.NAME), new Object[0]), pName}));
                if (player != null) {
                    NetQuestSync.sendSync(player, new int[]{id}, false, true);
                }
            } else {
                quest.resetUser((UUID) null, true);
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.reset.all_single", new Object[]{new ChatComponentTranslation((String) quest.getProperty(NativeProps.NAME), new Object[0])}));
                NetQuestSync.quickSync(id, false, true);
            }
        } catch (Exception e) {
            throw getException(command);
        }
    }

    public boolean isArgUsername(String[] args, int index) {
        return index == 2;
    }
}
